#include "windows.bi"


enum MONITOR_DPI_TYPE
  MDT_EFFECTIVE_DPI  = 0,
  MDT_ANGULAR_DPI    = 1,
  MDT_RAW_DPI        = 2,
  MDT_DEFAULT        = MDT_EFFECTIVE_DPI
end enum


type FunGetDpiForMonitor as function (hMonitor as HMONITOR, dpiType as MONITOR_DPI_TYPE, dpiX as UINT ptr, dpiY as UINT ptr) as HRESULT
dim shared GetDpiForMonitor as FunGetDpiForMonitor

dim as HMODULE hModShCore = LoadLibrary("Shcore.dll")
if (hModShCore <> 0) then
	GetDpiForMonitor = cast(FunGetDpiForMonitor, GetProcAddress(hModShCore, @"GetDpiForMonitor"))
end if


type NTSTATUS as long

type FunRtlGetVersion as function (lpVersionInformation as PRTL_OSVERSIONINFOW) as NTSTATUS
dim shared RtlGetVersion as FunRtlGetVersion

dim as HMODULE hModNtDll = LoadLibrary("Ntdll.dll")
if (hModNtDll <> 0) then
	RtlGetVersion = cast(FunRtlGetVersion, GetProcAddress(hModNtDll, @"RtlGetVersion"))
end if




function monitorEnumCallback (hMonitor as HMONITOR, hdcMonitor as HDC, lprcMonitor as LPRECT, dwData as LPARAM) as BOOL
	static as integer monitorNo = 0
	monitorNo += 1
	
	dim monInfo as MONITORINFOEX
	monInfo.cbSize = sizeof(MONITORINFOEX)
	GetMonitorInfo(hMonitor, cptr(MONITORINFO ptr, @monInfo))
	
	print "Monitor #" ; monitorNo; iif(monInfo.dwFlags and MONITORINFOF_PRIMARY, " (primary)", "")
	print " - name: "; monInfo.szDevice
	print " - size: "; abs(lprcMonitor->right - lprcMonitor->left); " x "; abs(lprcMonitor->bottom - lprcMonitor->top)
	print " - area: ("; lprcMonitor->left; ", "; lprcMonitor->top; ") - ("; lprcMonitor->right; ", "; lprcMonitor->bottom; ")"
	
	if (GetDpiForMonitor <> 0) then
		dim as long dpiX, dpiY
		GetDpiForMonitor(hMonitor, MDT_EFFECTIVE_DPI, @dpiX, @dpiY)
		print " - DPI eff:"; dpiX; ", "; dpiY
		GetDpiForMonitor(hMonitor, MDT_RAW_DPI, @dpiX, @dpiY)
		print " - DPI raw:"; dpiX; ", "; dpiY
	end if
	
	return TRUE
end function



dim as OSVERSIONINFOEX verInfo
verInfo.dwOSVersionInfoSize = sizeof(OSVERSIONINFOEX)

GetVersionEx(cptr(OSVERSIONINFO ptr, @verInfo))

if verInfo.dwMajorVersion < 6 then

	with verInfo
		print "Windows version "; str(.dwMajorVersion) + "." + str(.dwMinorVersion)
		print " - build " + str(.dwBuildNumber)
		print " - service pack " + str(.wServicePackMajor) + "." + str(.wServicePackMinor)
	end with

else

	dim as RTL_OSVERSIONINFOEXW verInfoNt
	verInfoNt.dwOSVersionInfoSize = sizeof(RTL_OSVERSIONINFOEXW)

	RtlGetVersion(cptr(OSVERSIONINFOW ptr, @verInfoNt))

	with verInfoNt
		print "Windows version "; str(.dwMajorVersion) + "." + str(.dwMinorVersion)
		print " - build " + str(.dwBuildNumber)
		print " - service pack " + str(.wServicePackMajor) + "." + str(.wServicePackMinor)
	end with

end if



dim as HDC dc = GetDC(NULL)
dim as long dpiX = GetDeviceCaps(dc, LOGPIXELSX)
dim as long dpiY = GetDeviceCaps(dc, LOGPIXELSY)
print "global dpi: "; dpiX; ", "; dpiY

EnumDisplayMonitors(NULL, NULL, @monitorEnumCallback, NULL)

sleep

